==> PgXexplorer-0.21.tar.bz2: PgXexplorer-0.21/consoleout.c <==
/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: consoleout.c */
#include "common.h"
#include "consoleout.h"

FILE* fopen_printf(char* mode, char* fmt, ...)
{
 va_list ap;
 char fnam[PATH];
 if (!fmt) return NULL;
 va_start(ap,fmt);
 vsprintf(fnam,fmt,ap);
 va_end(ap);
 return fopen(fnam,mode);
}


int debug(char* fmt, ...)
{
#ifdef DEBUG
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("debug: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 printf("\n");
 fflush(stdout);
 return err;
#endif
#ifndef DEBUG
 return 0;
#endif
}


int fatal(char* fmt, ...)
{
 va_list ap;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("\n\nPANIC\n\t%c%cfatal: ",7,7);
 vprintf(fmt,ap);
 printf("\nApplication Terminated.%c%c\n\n", 7,7);
 va_end(ap);
 fflush(stdout);
 exit(1);
}


void downcase(char* ptr)
{
 int i;
 int s;
 debug("%s:%d",__FILE__,__LINE__);
 if (!ptr) return;
 s = strlen(ptr);
 for (i=0;i<s;i++) if (ptr[i]>='A' && ptr[i]<='Z') ptr[i]+=0x20;
}


int error(char* fmt, ...)
{
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("error: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 fflush(stdout);
 return err;
}


int warn(char* fmt, ...)
{
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("warning: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 return err;
}


int system_printf(char* fmt, ...)
{
 va_list ap;
 char syscmd[MAX_SYSTEM_CMD];
 debug("%s:%d",__FILE__,__LINE__);
 if (!fmt) return -1;
 va_start(ap,fmt);
 vsprintf(syscmd,fmt,ap);
 va_end(ap);
 return system(syscmd);
}


void print_results(char*** res, int a, int b)
{
 int i,j;
 debug("%s:%d",__FILE__,__LINE__);
 ln();
 if (!res) return;
 for (i=0;i<a;i++)
   {
    if (res[i]) for (j=0;j<b;j++) if (res[i][j]) printf("%-16s ", res[i][j]);
    ln();
   }
 ln();
}

==> PgXexplorer-0.24.tar.bz2: PgXexplorer-0.24/consoleout.c <==
/* Written by Morgoth DBMA, morgothdbma@o2.pl
 This is part of PgXexplorer software, Open Source
 on BSD licence, Libraries(interaces) used:
 GNU GCC, AS (all stuff needed to compile C source into executable binary)
 LibPQ-FE from PostgreSQL, GTK (GIMP Toolkit)
 written in VIM editor, ctags used, CVS used
 Currently only one author: MOrgoth DBMA
 FILE: consoleout.c */
#include "common.h"
#include "consoleout.h"
#include "mmsystem.h"

FILE* fopen_printf(char* mode, char* fmt, ...)
{
 va_list ap;
 char fnam[PATH];
 debug("%s:%d fopen_printf",__FILE__,__LINE__);
 if (!fmt) return NULL;
 va_start(ap,fmt);
 vsprintf(fnam,fmt,ap);
 va_end(ap);
 return fopen(fnam,mode);
}

int sdebug(char* fmt, ...)
{
#ifdef DEBUG
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("debug: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 printf("\n");
 fflush(stdout);
 return err;
#else
#ifdef SMALLOC
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("debug: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 printf("\n");
 fflush(stdout);
 return err;
#else
 return 0;
#endif
#endif
}

int debug(char* fmt, ...)
{
#ifdef DEBUG
 va_list ap;
 int err;
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("debug: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 printf("\n");
 fflush(stdout);
 return err;
#endif
#ifndef DEBUG
 return 0;
#endif
}


int fatal(char* fmt, ...)
{
 va_list ap;
 debug("%s:%d fatal",__FILE__,__LINE__);
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("\n\nPANIC\n\t%c%cfatal: ",7,7);
 vprintf(fmt,ap);
 printf("\nApplication Terminated.%c%c\n\n", 7,7);
 va_end(ap);
 printf("\nSend a bug report to: morgothdbma@o2.pl\n");
 fflush(stdout);
 exit(1);
}

int fatal_here(char* file, int line, char* fmt, ...)
{
 va_list ap;
 debug("%s:%d fatal",__FILE__,__LINE__);
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("\n\nPANIC FROM FILE: %s, LINE: %d\n\t%c%cfatal: ",file,line,7,7);
 vprintf(fmt,ap);
 printf("\nApplication Terminated.%c%c\n\n", 7,7);
 va_end(ap);
 printf("PostMortem MemDump (global_memlist)\n");
#ifdef SMALLOC
 dprint_memlist(HERE);
#else
 print_memlist();
#endif
 printf("\nSend a bug report to: morgothdbma@o2.pl\n");
 fflush(stdout);
 exit(1);
}


void downcase(char* ptr)
{
 int i;
 int s;
 debug("%s:%d downcase",__FILE__,__LINE__);
 if (!ptr) return;
 s = strlen(ptr);
 for (i=0;i<s;i++) if (ptr[i]>='A' && ptr[i]<='Z') ptr[i]+=0x20;
}


int error(char* fmt, ...)
{
 va_list ap;
 int err;
 debug("%s:%d error",__FILE__,__LINE__);
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("error: ");
 err = vprintf(fmt,ap);
 va_end(ap);
 printf("\n");
 fflush(stdout);
 return err;
}


int warn(char* fmt, ...)
{
 va_list ap;
 int err;
 debug("%s:%d warn",__FILE__,__LINE__);
 if (!fmt) return -1;
 va_start(ap,fmt);
 printf("warning: ");
 err = vprintf(fmt,ap);
 printf("\n");
 fflush(stdout);
 va_end(ap);
 return err;
}


int system_printf(char* fmt, ...)
{
 va_list ap;
 char syscmd[MAX_SYSTEM_CMD];
 debug("%s:%d system_printf",__FILE__,__LINE__);
 debug("system_printf: %s", fmt);
 if (!fmt) return -1;
 va_start(ap,fmt);
 vsprintf(syscmd,fmt,ap);
 va_end(ap);
 return system(syscmd);
}


void print_results(char*** res, int a, int b)
{
 int i,j;
 debug("%s:%d print_results",__FILE__,__LINE__);
 ln();
 if (!res) return;
 for (i=0;i<a;i++)
   {
    if (res[i]) for (j=0;j<b;j++) if (res[i][j]) printf("%-16s ", res[i][j]);
    ln();
   }
 ln();
}
